import_utils

import_utils

Functions

Name Description
import_module Import a module or attribute from a dotted module path.

import_module

import_utils.import_module(module_path)

Import a module or attribute from a dotted module path.

Args: module_path (str): The dotted path to the module or attribute, e.g., ‘package.module.myclass’.

Returns: The imported object (module, class, function, or any other attribute).