network.download

network.download

Functions

Name Description
download_url Download url to dirname

download_url

network.download.download_url(
    url,
    dirname,
    wget_opts=None,
    check_function=None,
    verbose=True,
    if_exists='skip',
    **kwargs,
)

Download url to dirname

Uses wget when wget_opts is provided, otherwise uses urllib.request Options wget_opts are added to wget command Uses a filegen wrapper Other kwargs are passed to filegen (lock_timeout, tmpdir, if_exists)

Returns the path to the downloaded file