pub fn load_custom_array(
path: impl AsRef<Path>,
create_array: mts_create_array_callback_t,
) -> Result<TensorMap, Error>Expand description
Load the serialized tensor map from the given path.
See the load function for more information on the data format.
All arrays will be created through the create_array callback.