static.singleton

static.singleton

Functions

Name Description
singleton Declare a Class as a singleton, which can only have a single instance at the same time

singleton

static.singleton.singleton(myclass)

Declare a Class as a singleton, which can only have a single instance at the same time - adds a instance() class method which returns the current instanced object