ascii_table
ascii_table
Classes
| Name | Description |
|---|---|
| ascii_table | A class to represent a table for displaying data in a formatted way. |
ascii_table
ascii_table.ascii_table(df, style=style(), colors={}, sides={}, max_width=35)A class to represent a table for displaying data in a formatted way.
Classes
| Name | Description |
|---|---|
| style | A class to define the style of a table using specific characters. |
style
ascii_table.ascii_table.style(
inner_vbar=True,
inner_hbar=False,
h_padding=1,
v_padding=0,
style='squared',
)A class to define the style of a table using specific characters.
Methods
| Name | Description |
|---|---|
| to_string | Generates an ascii representation of the dataset provided in the constructor. |
to_string
ascii_table.ascii_table.to_string(live_print=False, no_color=True)Generates an ascii representation of the dataset provided in the constructor.