monitor
monitor
Classes
| Name | Description |
|---|---|
| Chrono | - name: str |
| Monitor | Meta-structure to monitor some variables in a script |
| RAM | - name: str |
Chrono
monitor.Chrono(name='chrono object', unit='m')- name: str
- unit “m” | “s” | “ms” | “us”
Monitor
monitor.Monitor(name='monitor object', time=None, ram=None)Meta-structure to monitor some variables in a script
RAM
monitor.RAM(name='ram object')- name: str
Functions
| Name | Description |
|---|---|
| dask_graph_stats | Get statistics about the dask graph for each variable in the dataset ds. |
dask_graph_stats
monitor.dask_graph_stats(ds)Get statistics about the dask graph for each variable in the dataset ds.
Returns a pandas DataFrame with the following columns: - var: The name of the variable. - graph_len: The length of the dask graph for the variable. - n_chunks: The number of chunks in the dask graph for the variable. - per_chunk: graph_len/n_chunks.
Example: >>> print(dask_graph_stats(ds).to_string(index=False))