static.interface
static.interface
Functions
| Name | Description |
|---|---|
| interface | Declare a function or method as an Interface |
interface
static.interface.interface(function)Declare a function or method as an Interface Raise an error if types passed do not match definition