table
table
Functions
| Name | Description |
|---|---|
| read_csv | Function to read csv file without taking care of tabulation and whitespaces |
| read_xml | Function to read xml file |
| select | Selection function in a pandas DataFrame with a condition |
| select_cell | Function for selecting a single cell value in a pandas DataFrame with a condition |
read_csv
table.read_csv(path, **kwargs)Function to read csv file without taking care of tabulation and whitespaces
Args: path (str | Path): Path of csv file kwargs: Keyword arguments of read_csv function from pandas
Returns: DataFrame: Output table in pandas DataFrame format
read_xml
table.read_xml(path)Function to read xml file
Args: path (str | Path): Path of xml file
select
table.select(table, where, cols=None)Selection function in a pandas DataFrame with a condition
Args: dataframe (pd.DataFrame): Input table from which to select where (tuple): Condition to use for the selection cols (str | list): Name of the columns to return
Example: select(df, (‘col_1’,‘=’,20), [‘col_2’,‘col_3’])
select_cell
table.select_cell(table, where, col)Function for selecting a single cell value in a pandas DataFrame with a condition
Args: dataframe (pd.DataFrame): Input table from which to select where (tuple): Condition to use for the selection col (str | list): Name of the column to return
Example: select_cell(df, (‘col_1’,‘=’,20), ‘col_2’)